import inquirer from 'inquirer';
const yesNoConfirmation = ({ type }) => ({
    name: 'confirmed',
    type: 'confirm',
    message: `Are you sure you want to delete this ${type}?`,
    default: false,
});
const inputValidation = ({ type, expectedValue, failureMessage, }) => ({
    name: 'confirmed',
    type: 'input',
    message: `Are you sure you want to delete this ${type}? If so, please type in "${expectedValue}":`,
    validate(value) {
        if (value === expectedValue) {
            return true;
        }
        return failureMessage;
    },
});
export async function confirmAction({ expectedValue, type, failureMessage, }) {
    const result = await inquirer.prompt(expectedValue ? inputValidation({ type, expectedValue, failureMessage }) : yesNoConfirmation({ type }));
    if (typeof result.confirmed === 'boolean') {
        return result.confirmed;
    }
    return result.confirmed === expectedValue;
}
//# sourceMappingURL=confirm.js.map