import Table from 'cli-table3';
const compactModeChars = {
    'mid': '',
    'left-mid': '',
    'mid-mid': '',
    'right-mid': '',
    middle: ' ',
    'top-mid': '─',
    'bottom-mid': '─',
};
const compactModeCharsWithLineSeparator = {
    middle: ' ',
    'top-mid': '─',
    'bottom-mid': '─',
    top: '─',
    bottom: '─',
    'left-mid': '├',
    mid: '─',
    'mid-mid': '─',
    'right-mid': '┤',
};
export var CompactMode;
(function (CompactMode) {
    /**
     * Print the table as is
     */
    CompactMode[CompactMode["None"] = -1] = "None";
    /**
     * Minimized version of the table, with no separators between rows
     */
    CompactMode[CompactMode["VeryCompact"] = 0] = "VeryCompact";
    /**
     * A version of the compact table that looks akin to the web console (fewer separators, but with lines between rows)
     */
    CompactMode[CompactMode["WebLikeCompact"] = 1] = "WebLikeCompact";
})(CompactMode || (CompactMode = {}));
const charMap = {
    [CompactMode.None]: undefined,
    [CompactMode.VeryCompact]: compactModeChars,
    [CompactMode.WebLikeCompact]: compactModeCharsWithLineSeparator,
};
function generateHeaderColors(length) {
    return Array.from({ length }, () => 'cyan');
}
const terminalColumns = process.stdout.columns ?? 100;
export class ResponsiveTable {
    options;
    rows = [];
    constructor(options) {
        this.options = options;
    }
    pushRow(item) {
        this.rows.push(item);
    }
    render(compactMode) {
        const head = terminalColumns < 100 ? this.options.mandatoryColumns : this.options.allColumns;
        const headColors = generateHeaderColors(head.length);
        const compact = compactMode === CompactMode.VeryCompact;
        const chars = charMap[compactMode];
        const colAligns = [];
        for (const column of head) {
            colAligns.push(this.options.columnAlignments?.[column] || 'left');
        }
        const table = new Table({
            head,
            style: {
                head: headColors,
                compact,
            },
            colAligns,
            chars,
        });
        for (const rowData of this.rows) {
            const row = head.map((col) => rowData[col]);
            table.push(row);
        }
        return table.toString();
    }
}
//# sourceMappingURL=responsive-table.js.map